@@ -18,7 +18,6 @@
 package org.apache.commons.daemon.support;
 
 import java.io.FileInputStream;
-import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Properties;
@@ -28,21 +27,21 @@ import java.text.ParseException;
  * Used by jsvc for Daemon configuration.
  * <p>
  * Configuration is read from properties file.
- * If no properties file is given the <code>daemon.properties</code>
+ * If no properties file is given the {@code daemon.properties}
  * is used from the current directory.
  * </p>
  * <p>
  * The properties file can have property values expanded at runtime
  * by using System properties or execution environment. The part
- * of the property value between <code>${</code> and <code>}</code>
+ * of the property value between {@code ${} and {@code }}
  * will be used as System property or environment key. If found then
- * the entire <code>${foo}</code> will be replaced by the value of
- * either system property or environment variable named <code>foo</code>.
+ * the entire {@code ${foo}} will be replaced by the value of
+ * either system property or environment variable named {@code foo}.
  * </p>
  * <p>
- * If no variable is found the <code>${foo}</code>  will be passed as is.
- * In case of <code>$${foo}</code> this will be unescaped and resulting
- * value will be <code>${foo}</code>.
+ * If no variable is found the {@code ${foo}}  will be passed as is.
+ * In case of {@code $${foo}} this will be unescaped and resulting
+ * value will be {@code ${foo}}.
  * </p>
  *
  */
@@ -63,6 +62,11 @@ public final class DaemonConfiguration
     private final Properties configurationProperties;
     private final Properties systemProperties;
 
+    /**
+     * An empty immutable {@code String} array.
+     */
+    static final String[] EMPTY_STRING_ARRAY = {};
+
     /**
      * Default constructor
      */
@@ -76,7 +80,7 @@ public final class DaemonConfiguration
      * Loads the configuration properties file.
      *
      * @param fileName The properties file to load.
-     * @return <code>true</code> if the file was loaded.
+     * @return {@code true} if the file was loaded.
      */
     public boolean load(String fileName)
     {
@@ -91,9 +95,6 @@ public final class DaemonConfiguration
             configurationProperties.load(file);
             ok = true;
         }
-        catch (final FileNotFoundException ex) {
-            // fileName does not exist
-        }
         catch (final IOException ex) {
             // Error reading properties file
         } finally {
@@ -110,14 +111,14 @@ public final class DaemonConfiguration
     private String expandProperty(final String propValue)
         throws ParseException
     {
-        StringBuffer expanded;
+        final StringBuilder expanded;
         int btoken;
         int ctoken = 0;
 
         if (propValue == null) {
             return null;
         }
-        expanded = new StringBuffer();
+        expanded = new StringBuilder();
         btoken   = propValue.indexOf(BTOKEN);
         while (btoken != -1) {
             if (btoken > 0 && propValue.charAt(btoken - 1) == BTOKEN.charAt(0)) {
@@ -128,30 +129,28 @@ public final class DaemonConfiguration
                 continue;
             }
             final int etoken = propValue.indexOf(ETOKEN, btoken);
-            if (etoken != -1) {
-                final String variable = propValue.substring(btoken + BTOKEN.length(), etoken);
-                String sysvalue = systemProperties.getProperty(variable);
-                if (sysvalue == null) {
-                    // Try with the environment if there was no
-                    // property by that name.
-                    sysvalue = System.getenv(variable); // N.B. Deprecated in Java 1.3/1.4, but re-instated in Java 1.5+
-                }
-                if (sysvalue != null) {
-                    final String strtoken = propValue.substring(ctoken, btoken);
-                    expanded.append(strtoken);
-                    expanded.append(sysvalue);
-                    ctoken = etoken + ETOKEN.length();
-                }
-            }
-            else {
+            if (etoken == -1) {
                 // We have "${" without "}"
                 throw new ParseException("Error while looking for teminating '" +
                                          ETOKEN + "'", btoken);
             }
+            final String variable = propValue.substring(btoken + BTOKEN.length(), etoken);
+            String sysvalue = systemProperties.getProperty(variable);
+            if (sysvalue == null) {
+                // Try with the environment if there was no
+                // property by that name.
+                sysvalue = System.getenv(variable);
+            }
+            if (sysvalue != null) {
+                final String strtoken = propValue.substring(ctoken, btoken);
+                expanded.append(strtoken);
+                expanded.append(sysvalue);
+                ctoken = etoken + ETOKEN.length();
+            }
             btoken = propValue.indexOf(BTOKEN, etoken + ETOKEN.length());
         }
         // Add what's left.
-        expanded.append(propValue.substring(ctoken, propValue.length()));
+        expanded.append(propValue.substring(ctoken));
         return expanded.toString();
     }
 
@@ -177,7 +176,7 @@ public final class DaemonConfiguration
      * Gets the configuration property array.
      * <p>
      * Property array is constructed form the list of properties
-     * which end with <code>[index]</code>
+     * which end with {@code [index]}
      * </p>
      * <pre>
      * daemon.arg[0] = argument 1
@@ -193,7 +192,7 @@ public final class DaemonConfiguration
     public String[] getPropertyArray(final String name)
         throws ParseException
     {
-        final ArrayList<String> list = new ArrayList<String>();
+        final ArrayList<String> list = new ArrayList<>();
         String    args;
 
         // Load daemon.arg[0] ... daemon.arg[n] into the String array.
@@ -201,7 +200,7 @@ public final class DaemonConfiguration
         while ((args = getProperty(name + "[" + list.size() + "]")) != null) {
             list.add(args);
         }
-        return list.toArray(new String[list.size()]);
+        return list.toArray(EMPTY_STRING_ARRAY);
     }
 }
 
